type gitLabIssue = {
    category: string,
    message: string,
    cve: string,
    severity: string,
    confidence: string,
    scanner: {
      id: string,
      name: string
    },
    location: {
      file: string,
      start_line: number,
      end_line: number
    },
    identifiers: [
      {
        type: string,
        name: string,
        value: string,
        url: string
      }
    ]
}

type sonarIssue = {
    key: string,
    rule: string,
    severity: string,
    component: string,
    project: string,
    line: number,
    hash: string,
    textRange: {
        startLine: number,
        endLine: number,
        startOffset: number,
        endOffset: number
    },
    flows: string[],
    status: string,
    message: string,
    effort: string,
    debt: string,
    author: string,
    tags: string [],
    creationDate: string,
    updateDate: string,
    type:string,
    scope: string,
    quickFixAvailable: boolean
}

const convert = (issues: sonarIssue[]) => {
    return issues.map((issue: sonarIssue) => {
        return {
            category: issue.rule,
            message: issue.message,
            cve: '',
            severity: issue.severity,
            confidence: '',
            scanner: {
                id: 'sonarqube',
                name: 'SonarQube'
            },
            location: {
                file: issue.component,
                start_line: issue.line,
                end_line: issue.line
            },
            identifiers: [
                {
                    type: 'SonarQube',
                    name: issue.key,
                    value: issue.key,
                    url: 'http://whyjihu.southeastasia.cloudapp.azure.com:9001/project/issues?id=www_public-example_sonar-qube-integration_AYQw63du1WXrh1AvkyAg&issues=' + issue.key + '&open=' + issue.key + '&pullRequest=0&resolved=false'
                }
            ]
        }
    });
}


export { gitLabIssue, sonarIssue, convert };